BasicControl

Struct BasicControl 

pub struct BasicControl { /* private fields */ }
The Control Register, containing basic control bits.

Implementations

Source

impl BasicControl

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const DEFAULT: Self

An instance that uses the default value 0

pub const fn new() -> Self

👎Deprecated:

Use BasicControl::Default (or BasicControl::DEFAULT in const context) instead

Creates a new instance of this struct using the default value

pub const fn raw_value(&self) -> u16

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u16) -> BasicControl

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialBasicControl<false, false, false, false, false, false, false, false, false, false, false>

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn unidirectional_enable(&self) -> bool

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn with_unidirectional_enable(&self, field_value: bool) -> Self

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub fn set_unidirectional_enable(&mut self, field_value: bool)

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn speed_sel_msb(&self) -> bool

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn with_speed_sel_msb(&self, field_value: bool) -> Self

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub fn set_speed_sel_msb(&mut self, field_value: bool)

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn collision_test(&self) -> bool

Enable the collision test signal.

pub const fn with_collision_test(&self, field_value: bool) -> Self

Enable the collision test signal.

pub fn set_collision_test(&mut self, field_value: bool)

Enable the collision test signal.

pub const fn duplex_mode(&self) -> Duplex

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn with_duplex_mode(&self, field_value: Duplex) -> Self

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub fn set_duplex_mode(&mut self, field_value: Duplex)

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn restart_autonegotiation(&self) -> bool

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn with_restart_autonegotiation(&self, field_value: bool) -> Self

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub fn set_restart_autonegotiation(&mut self, field_value: bool)

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn isolate(&self) -> bool

Electrically isolate the PHY from its (Gigabit) Media Independent Interface.

In other words, disconnect the PHY from the pins it shares with the MAC component connected to it. Setting this bit does retain access to the PHY over MIIM.

pub const fn with_isolate(&self, field_value: bool) -> Self

Electrically isolate the PHY from its (Gigabit) Media Independent Interface.

In other words, disconnect the PHY from the pins it shares with the MAC component connected to it. Setting this bit does retain access to the PHY over MIIM.

pub fn set_isolate(&mut self, field_value: bool)

Electrically isolate the PHY from its (Gigabit) Media Independent Interface.

In other words, disconnect the PHY from the pins it shares with the MAC component connected to it. Setting this bit does retain access to the PHY over MIIM.

pub const fn power_down(&self) -> bool

Enable Power-Down mode.

pub const fn with_power_down(&self, field_value: bool) -> Self

Enable Power-Down mode.

pub fn set_power_down(&mut self, field_value: bool)

Enable Power-Down mode.

pub const fn autonegotiation_enable(&self) -> bool

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn with_autonegotiation_enable(&self, field_value: bool) -> Self

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub fn set_autonegotiation_enable(&mut self, field_value: bool)

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn speed_sel_lsb(&self) -> bool

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn with_speed_sel_lsb(&self, field_value: bool) -> Self

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub fn set_speed_sel_lsb(&mut self, field_value: bool)

Do not access this field directly: use BasicControl::set_link_config and BasicControl::get_link_config instead.

pub const fn loopback(&self) -> bool

Enable loopback mode.

pub const fn with_loopback(&self, field_value: bool) -> Self

Enable loopback mode.

pub fn set_loopback(&mut self, field_value: bool)

Enable loopback mode.

pub const fn reset(&self) -> bool

Perform a reset.

If set, this bit will stay high until the reset has completed.

pub const fn with_reset(&self, field_value: bool) -> Self

Perform a reset.

If set, this bit will stay high until the reset has completed.

pub fn set_reset(&mut self, field_value: bool)

Perform a reset.

If set, this bit will stay high until the reset has completed.

Source

impl BasicControl

Get the current link configuration.

Set the link configuration to config.