pub struct GetLinkStateProcess;Expand description
A state machine describing the process of determining the link state of an (R)(G)MII PHY.
Each step in the process returns a ControlFlow. The Break
variant indicates that a result has been obtained, while the Continue variant indicates
that additional register reads are required. The value in the Continue variant will
have a next function to drive the process further.
Implementations
Sourceimpl GetLinkStateProcess
impl GetLinkStateProcess
Sourcepub fn oneshot(
status: BasicStatus,
control: BasicControl,
autoneg_exp: AutonegotiationExpansion,
advertisement: AutonegotiationAdvertisement,
link_partner_ability: AutonegotiationLinkPartnerAbility,
lf_control: LeaderFollowerControl,
lf_status: LeaderFollowerStatus,
) -> Result<LinkState, LinkStateError>
pub fn oneshot( status: BasicStatus, control: BasicControl, autoneg_exp: AutonegotiationExpansion, advertisement: AutonegotiationAdvertisement, link_partner_ability: AutonegotiationLinkPartnerAbility, lf_control: LeaderFollowerControl, lf_status: LeaderFollowerStatus, ) -> Result<LinkState, LinkStateError>
Perform the process in a single shot by providing all of the registers necessary to perform the determination.
Sourcepub fn start(
status: BasicStatus,
control: BasicControl,
) -> ControlFlow<Result<LinkState, LinkStateError>, Autonegotiating>
pub fn start( status: BasicStatus, control: BasicControl, ) -> ControlFlow<Result<LinkState, LinkStateError>, Autonegotiating>
Start the process of determining the link state of a PHY.