pub struct BasicControl { /* private fields */ }Expand description
The Control Register, containing basic control bits.
Implementations
Sourceimpl BasicControl
impl BasicControl
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new() -> Self
👎Deprecated: Use BasicControl::Default (or BasicControl::DEFAULT in const context) instead
pub const fn new() -> Self
Use BasicControl::Default (or BasicControl::DEFAULT in const context) instead
Creates a new instance of this struct using the default value
Sourcepub const fn new_with_raw_value(value: u16) -> BasicControl
pub const fn new_with_raw_value(value: u16) -> BasicControl
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialBasicControl<false, false, false, false, false, false, false, false, false, false, false>
pub const fn builder() -> PartialBasicControl<false, false, false, false, false, false, false, false, false, false, false>
Creates a builder for this bitfield which ensures that all writable fields are initialized.
Sourcepub const fn unidirectional_enable(&self) -> bool
pub const fn unidirectional_enable(&self) -> bool
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn with_unidirectional_enable(&self, field_value: bool) -> Self
pub const fn with_unidirectional_enable(&self, field_value: bool) -> Self
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub fn set_unidirectional_enable(&mut self, field_value: bool)
pub fn set_unidirectional_enable(&mut self, field_value: bool)
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn speed_sel_msb(&self) -> bool
pub const fn speed_sel_msb(&self) -> bool
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn with_speed_sel_msb(&self, field_value: bool) -> Self
pub const fn with_speed_sel_msb(&self, field_value: bool) -> Self
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub fn set_speed_sel_msb(&mut self, field_value: bool)
pub fn set_speed_sel_msb(&mut self, field_value: bool)
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn collision_test(&self) -> bool
pub const fn collision_test(&self) -> bool
Enable the collision test signal.
Sourcepub const fn with_collision_test(&self, field_value: bool) -> Self
pub const fn with_collision_test(&self, field_value: bool) -> Self
Enable the collision test signal.
Sourcepub fn set_collision_test(&mut self, field_value: bool)
pub fn set_collision_test(&mut self, field_value: bool)
Enable the collision test signal.
Sourcepub const fn duplex_mode(&self) -> Duplex
pub const fn duplex_mode(&self) -> Duplex
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn with_duplex_mode(&self, field_value: Duplex) -> Self
pub const fn with_duplex_mode(&self, field_value: Duplex) -> Self
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub fn set_duplex_mode(&mut self, field_value: Duplex)
pub fn set_duplex_mode(&mut self, field_value: Duplex)
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn restart_autonegotiation(&self) -> bool
pub const fn restart_autonegotiation(&self) -> bool
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn with_restart_autonegotiation(&self, field_value: bool) -> Self
pub const fn with_restart_autonegotiation(&self, field_value: bool) -> Self
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub fn set_restart_autonegotiation(&mut self, field_value: bool)
pub fn set_restart_autonegotiation(&mut self, field_value: bool)
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn isolate(&self) -> bool
pub const fn isolate(&self) -> bool
Electrically isolate the PHY from its (Gigabit) Media Independent Interface.
In other words, disconnect the PHY from the pins it shares with the MAC component connected to it. Setting this bit does retain access to the PHY over MIIM.
Sourcepub const fn with_isolate(&self, field_value: bool) -> Self
pub const fn with_isolate(&self, field_value: bool) -> Self
Electrically isolate the PHY from its (Gigabit) Media Independent Interface.
In other words, disconnect the PHY from the pins it shares with the MAC component connected to it. Setting this bit does retain access to the PHY over MIIM.
Sourcepub fn set_isolate(&mut self, field_value: bool)
pub fn set_isolate(&mut self, field_value: bool)
Electrically isolate the PHY from its (Gigabit) Media Independent Interface.
In other words, disconnect the PHY from the pins it shares with the MAC component connected to it. Setting this bit does retain access to the PHY over MIIM.
Sourcepub const fn power_down(&self) -> bool
pub const fn power_down(&self) -> bool
Enable Power-Down mode.
Sourcepub const fn with_power_down(&self, field_value: bool) -> Self
pub const fn with_power_down(&self, field_value: bool) -> Self
Enable Power-Down mode.
Sourcepub fn set_power_down(&mut self, field_value: bool)
pub fn set_power_down(&mut self, field_value: bool)
Enable Power-Down mode.
Sourcepub const fn autonegotiation_enable(&self) -> bool
pub const fn autonegotiation_enable(&self) -> bool
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn with_autonegotiation_enable(&self, field_value: bool) -> Self
pub const fn with_autonegotiation_enable(&self, field_value: bool) -> Self
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub fn set_autonegotiation_enable(&mut self, field_value: bool)
pub fn set_autonegotiation_enable(&mut self, field_value: bool)
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn speed_sel_lsb(&self) -> bool
pub const fn speed_sel_lsb(&self) -> bool
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn with_speed_sel_lsb(&self, field_value: bool) -> Self
pub const fn with_speed_sel_lsb(&self, field_value: bool) -> Self
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub fn set_speed_sel_lsb(&mut self, field_value: bool)
pub fn set_speed_sel_lsb(&mut self, field_value: bool)
Do not access this field directly: use BasicControl::set_link_config
and BasicControl::get_link_config instead.
Sourcepub const fn with_loopback(&self, field_value: bool) -> Self
pub const fn with_loopback(&self, field_value: bool) -> Self
Enable loopback mode.
Sourcepub fn set_loopback(&mut self, field_value: bool)
pub fn set_loopback(&mut self, field_value: bool)
Enable loopback mode.
Sourcepub const fn reset(&self) -> bool
pub const fn reset(&self) -> bool
Perform a reset.
If set, this bit will stay high until the reset has completed.
Sourcepub const fn with_reset(&self, field_value: bool) -> Self
pub const fn with_reset(&self, field_value: bool) -> Self
Perform a reset.
If set, this bit will stay high until the reset has completed.
Sourceimpl BasicControl
impl BasicControl
Sourcepub fn get_link_config(&self) -> LinkConfig
pub fn get_link_config(&self) -> LinkConfig
Get the current link configuration.
Sourcepub fn set_link_config(&mut self, config: LinkConfig)
pub fn set_link_config(&mut self, config: LinkConfig)
Set the link configuration to config.